@@ -28,23 +28,36 @@ NULL
 #'
 #' Contents are only stored as numbers if a whole column is numeric as defined by [is_a_number()];
 #' otherwise they are stored as text.
+#'
 #' @return An object of class `Workbook`.
 #' @export
 #'
 #' @examples
 #' ht <- hux(a = 1:3, b = 1:3)
 #' wb <- as_Workbook(ht)
+#'
 #' \dontrun{
 #' openxlsx::saveWorkbook(wb, "my-excel-file.xlsx")
 #' }
+#'
+#' # multiple sheets in a single workbook:
+#' wb <- openxlsx::createWorkbook()
+#' wb <- as_Workbook(ht, Workbook = wb, sheet = 'sheet1')
+#' wb <- as_Workbook(hux('Another', 'huxtable'), Workbook = wb, sheet = 'sheet2')
 as_Workbook <- function (ht, ...) UseMethod('as_Workbook')
 
+
+memo_env <- new.env()
+
 #' @export
 #' @rdname as_Workbook
 as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write_caption = TRUE, ...) {
   assert_package('as_Workbook', 'openxlsx')
   assert_that(is.string(sheet))
 
+  if (! exists('memoised_createStyle', where = memo_env)) {
+    memo_env$memoised_createStyle <- memoise::memoise(openxlsx::createStyle)
+  }
   wb <- if (missing(Workbook) || is.null(Workbook)) openxlsx::createWorkbook() else Workbook
   openxlsx::addWorksheet(wb, sheet)
 
@@ -61,6 +74,31 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
   }
 
   contents <- clean_contents(ht, type = 'excel') # character matrix
+
+  nr <- nrow(contents)
+  contents <- as.data.frame(contents, stringsAsFactors = FALSE)
+  is_a_number_mx <- is_a_number(contents)
+  # for each column we go down it. If everything remaining is one type, we insert it. Otherwise
+  # we insert the cell.
+  for (j in seq_len(ncol(contents))) {
+    col_contents <- contents[[j]]
+    for (i in seq_len(nr)) {
+      is_a_number_col <- is_a_number_mx[i:nr, j]
+      if (all(is_a_number_col) || all(! is_a_number_col)) {
+        insert <- col_contents[i:nr]
+        if (all(is_a_number_col)) insert <- as.numeric(insert)
+        openxlsx::writeData(wb, sheet, insert, startRow = 1 * top_cap + i, startCol = j,
+              colNames = FALSE, rowNames = FALSE, borders = 'none', borderStyle = 'none')
+        break # to the next column
+      } else {
+        insert <- col_contents[i]
+        if (is_a_number_col[1]) insert <- as.numeric(insert)
+        openxlsx::writeData(wb, sheet, insert, startRow = 1 * top_cap + i, startCol = j,
+            colNames = FALSE, rowNames = FALSE, borders = 'none', borderStyle = 'none')
+      }
+    }
+  }
+
   dcells <- display_cells(ht, all = FALSE)
   for (r in seq_len(nrow(dcells))) {
     dcell <- dcells[r, ]
@@ -69,13 +107,8 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
 
     workbook_rows <- seq(drow, dcell$end_row)
     workbook_cols <- seq(dcol, dcell$end_col)
-    cell_contents <- contents[drow, dcol]
-    if (is_a_number(cell_contents)) cell_contents <- as.numeric(cell_contents)
     if (top_cap) workbook_rows <- workbook_rows + 1
 
-    openxlsx::writeData(wb, sheet, cell_contents, startRow = min(workbook_rows), startCol = dcol,
-          colNames = FALSE, rowNames = FALSE, borders = 'none', borderStyle = 'none')
-
     null_args <- list()
     null_args$tc <- text_color(ht)[drow, dcol]
     null_args$fs <- font_size(ht)[drow, dcol]
@@ -86,23 +119,29 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
     nf <- number_format(ht)[[drow, dcol]] # double brackets needed here
     format_zero <- format_numbers(0, nf)
     num_fmt <- if (grepl("^0\\.0+$", format_zero)) format_zero else
-          if (is.numeric(cell_contents)) 'NUMBER' else 'GENERAL'
+          if (is.numeric(contents[drow, dcol])) 'NUMBER' else 'GENERAL'
     borders <- get_all_borders(ht, drow, dcol) # list of numerics
     border_char <- names(borders)
     border_colors <- get_all_border_colors(ht, drow, dcol)
     border_colors <- unlist(border_colors[border_char])
     border_colors[is.na(border_colors)] <- getOption('openxlsx.borderColour', 'black')
-    border_style <- cut(unlist(borders), c(-1, 0, 0.5, 1, 2, Inf), labels = FALSE)
-    border_style <- c("none", "hair", "thin", "medium", "thick")[border_style]
+    border_styles <- get_all_border_styles(ht, drow, dcol)
+    border_styles <- unlist(border_styles[border_char])
+    border_styles[border_styles == "solid"] <- as.character(cut(
+            unlist(borders[border_styles == "solid"]),
+            c(-1, 0, 0.5, 1, 2, Inf),
+            labels = c("none", "hair", "thin", "medium", "thick")
+          ))
     va           <- valign(ht)[drow, dcol]
-    style <- openxlsx::createStyle(
+
+    style <- memo_env$memoised_createStyle(
             fontName       = null_args$ft,
             fontSize       = null_args$fs,
             fontColour     = null_args$tc,
             numFmt         = num_fmt,
             border         = border_char,
             borderColour   = border_colors,
-            borderStyle    = border_style,
+            borderStyle    = border_styles,
             fgFill         = null_args$bgc, # bgFill is "for conditional formatting only"
             halign         = real_align(ht)[drow, dcol],
             valign         = switch(va, middle = 'center', va),
@@ -130,3 +169,6 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
 
   return(wb)
 }
+
+
+
