@@ -52,13 +52,13 @@ test_that('huxreg confidence intervals work when tidy c.i.s not available', {
   if (packageVersion('broom') >= '0.7.0') skip_if_not_installed('broom.mixed')
 
   set.seed(27101975)
-  library(nlme)
   data(Orthodont, package = 'nlme')
   # method ML avoids a warning in broom::glance
   fm1 <- nlme::lme(distance ~ age + Sex, data = Orthodont, random = ~ 1, method = 'ML')
-  expect_silent(
+  expect_error(
           huxreg(fm1, tidy_args = list(effects = 'fixed'), statistics = 'nobs', ci_level = 0.95,
-          error_format = '({conf.low}-{conf.high})')
+                error_format = '({conf.low}-{conf.high})'),
+          regexp = NA
         )
 
 })
